@@ -1,6 +1,6 @@
 
 /*
- * $Id: net_db.c,v 1.31.2.15 1997/03/29 06:51:42 wessels Exp $
+ * $Id: net_db.c,v 1.31.2.17 1997/04/23 19:38:42 wessels Exp $
  *
  * DEBUG: section 37    Network Measurement Database
  * AUTHOR: Duane Wessels
@@ -373,7 +373,7 @@ netdbReloadState(void)
 	memset(&N, '\0', sizeof(netdbEntry));
 	if ((t = strtok(buf, w_space)) == NULL)
 	    continue;
-	if ((addr.s_addr = inet_addr(t)) == inaddr_none)
+	if (!safe_inet_addr(t, &addr))
 	    continue;
 	if ((t = strtok(NULL, w_space)) == NULL)
 	    continue;
