@@ -1,6 +1,6 @@
 
 /*
- * $Id: squid.h,v 1.95.2.15 1997/04/24 17:41:17 wessels Exp $
+ * $Id: squid.h,v 1.95.2.17 1997/05/31 23:29:23 wessels Exp $
  *
  * AUTHOR: Duane Wessels
  *
@@ -88,7 +88,9 @@
 #if HAVE_GRP_H
 #include <grp.h>
 #endif
-#if HAVE_MALLOC_H && !defined(_SQUID_FREEBSD_) && !defined(_SQUID_NEXT_)
+#if HAVE_GNUMALLOC_H
+#include <gnumalloc.h>
+#elif HAVE_MALLOC_H && !defined(_SQUID_FREEBSD_) && !defined(_SQUID_NEXT_)
 #include <malloc.h>
 #endif
 #if HAVE_MEMORY_H
@@ -332,6 +334,7 @@ extern int opt_no_ipcache;	/* main.c */
 extern int vhost_mode;		/* main.c */
 extern int Squid_MaxFD;		/* main.c */
 extern int Biggest_FD;		/* main.c */
+extern int Number_FD;		/* main.c */
 extern int select_loops;	/* main.c */
 extern const char *const version_string;	/* main.c */
 extern const char *const appname;	/* main.c */
