@@ -1,6 +1,6 @@
 
 /*
- * $Id: url.c,v 1.54.2.3 1997/06/05 15:58:59 wessels Exp $
+ * $Id: url.c,v 1.54.2.4 1997/07/04 06:06:08 wessels Exp $
  *
  * DEBUG: section 23    URL Parsing
  * AUTHOR: Duane Wessels
@@ -299,6 +299,31 @@ urlCanonical(const request_t * request, char *buf)
     return buf;
 }
 
+char *
+urlNoLogin(const request_t * request, char *buf)
+{
+    LOCAL_ARRAY(char, urlbuf, MAX_URL);
+    LOCAL_ARRAY(char, portbuf, 32);
+    if (buf == NULL)
+	buf = urlbuf;
+    switch (request->method) {
+    case METHOD_CONNECT:
+	sprintf(buf, "%s:%d", request->host, request->port);
+	break;
+    default:
+	portbuf[0] = '\0';
+	if (request->port != urlDefaultPort(request->protocol))
+	    sprintf(portbuf, ":%d", request->port);
+	sprintf(buf, "%s://%s%s%s",
+	    ProtocolStr[request->protocol],
+	    request->host,
+	    portbuf,
+	    request->urlpath);
+	break;
+    }
+    return buf;
+}
+
 request_t *
 requestLink(request_t * request)
 {
